###########################################
CCD (2D Data) Processing and Transformation
###########################################

.. toctree::
   :maxdepth: 2

   ccd_intro
   ccd_FileProcessor
   ccd_ImageProcessor
   ccd_formats
   ccd_ctrans
   ccd_plotting
   ccd_sterror

The ``pyspec`` package contains a ccd module (``pyspec.ccd``) for
processing 2D images, and performing the resulting reciprocal space
transformations. This doccumentation outlines the use of this code.

   
